@@ -43,7 +43,8 @@ impl<T: Type, const LEN: usize> Type for [T; LEN] {
 }
 
 impl<T: ParseFromJSON, const LEN: usize> ParseFromJSON for [T; LEN] {
-    fn parse_from_json(value: Value) -> ParseResult<Self> {
+    fn parse_from_json(value: Option<Value>) -> ParseResult<Self> {
+        let value = value.unwrap_or_default();
         match value {
             Value::Array(values) => {
                 if values.len() != LEN {
@@ -55,7 +56,7 @@ impl<T: ParseFromJSON, const LEN: usize> ParseFromJSON for [T; LEN] {
 
                 let mut res = Vec::with_capacity(values.len());
                 for value in values {
-                    res.push(T::parse_from_json(value).map_err(ParseError::propagate)?);
+                    res.push(T::parse_from_json(Some(value)).map_err(ParseError::propagate)?);
                 }
 
                 Ok(res.try_into().ok().unwrap())
