@@ -39,7 +39,8 @@ impl Type for Url {
 }
 
 impl ParseFromJSON for Url {
-    fn parse_from_json(value: Value) -> ParseResult<Self> {
+    fn parse_from_json(value: Option<Value>) -> ParseResult<Self> {
+        let value = value.unwrap_or_default();
         if let Value::String(value) = value {
             Ok(value.parse()?)
         } else {
